@@ -1,7 +1,7 @@
 package Sidef {
 
     use 5.014;
-    our $VERSION = '2.330001';
+    our $VERSION = '2.34';
 
     our $SPACES      = 0;    # the current number of spaces
     our $SPACES_INCR = 4;    # the number of spaces incrementor
@@ -446,7 +446,7 @@ package Sidef {
         eval { require $self =~ s{::}{/}rg . '.pm' };
 
         if ($@) {
-            if (defined &main::__load_sidef_module__) {
+            if (defined(&main::__load_sidef_module__)) {
                 main::__load_sidef_module__($self);
             }
             else {
@@ -455,7 +455,10 @@ package Sidef {
         }
 
         if (defined(&$AUTOLOAD)) {
-            return $AUTOLOAD->($self, @args);
+            goto \&$AUTOLOAD;
+
+            ## The above `goto` is roughly equivalent with:
+            #return $AUTOLOAD->($self, @args);
         }
     }
 
