@@ -77,7 +77,8 @@ package Sidef::Deparse::Sidef {
         my ($self, $before, $sep, $after, @args) = @_;
         $before . join(
             $sep,
-            map {
+            grep { $_ ne '' }
+              map {
                     ref($_) eq 'HASH' ? $self->deparse_script($_)
                   : ref($_) ? $self->deparse_expr({self => $_})
                   : $self->_dump_string($_)
@@ -557,6 +558,7 @@ package Sidef::Deparse::Sidef {
 
         # Array and hash indices
         if (exists $expr->{ind}) {
+            $code = "($code)";
             foreach my $ind (@{$expr->{ind}}) {
                 if (exists $ind->{array}) {
                     $code .= $self->_dump_array($ind->{array});
@@ -585,7 +587,7 @@ package Sidef::Deparse::Sidef {
                 if (defined $method) {
 
                     if (ref($method) ne '') {
-                        $code .= '.'
+                        $code .= '->'
                           . (
                              '('
                                . $self->deparse_expr(
@@ -620,7 +622,7 @@ package Sidef::Deparse::Sidef {
                             $code .= $method;
                         }
                         else {
-                            $code = "($code) $method ";
+                            $code = "($code)->$method";
                         }
                     }
                 }
