@@ -315,6 +315,8 @@ package Sidef::Types::Number::Complex {
         bless(\$r, __PACKAGE__);
     }
 
+    *fadd = \&add;
+
     sub sub {
         my ($x, $y) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
@@ -330,6 +332,8 @@ package Sidef::Types::Number::Complex {
         bless(\$r, __PACKAGE__);
     }
 
+    *fsub = \&sub;
+
     sub mul {
         my ($x, $y) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
@@ -345,6 +349,8 @@ package Sidef::Types::Number::Complex {
         bless(\$r, __PACKAGE__);
     }
 
+    *fmul = \&mul;
+
     sub div {
         my ($x, $y) = @_;
 
@@ -361,6 +367,8 @@ package Sidef::Types::Number::Complex {
         bless(\$r, __PACKAGE__);
     }
 
+    *fdiv = \&div;
+
     sub inv {
         my ($x) = @_;
 
@@ -385,6 +393,8 @@ package Sidef::Types::Number::Complex {
         bless(\$r, __PACKAGE__);
     }
 
+    *fpow = \&pow;
+
     sub root {
         my ($x, $y) = @_;
         return $x->pow($y->inv);
@@ -410,6 +420,25 @@ package Sidef::Types::Number::Complex {
         bless(\$r, __PACKAGE__);
     }
 
+    sub hypot {
+        my ($x, $y) = @_;
+
+        my $r = Math::MPFR::Rmpfr_init2($PREC);
+        Math::MPC::Rmpc_abs($r, $$x, $ROUND);
+
+        if (ref($y) eq 'Sidef::Types::Number::Number') {
+            Math::MPFR::Rmpfr_hypot($r, $r, $y->_big2mpfr, $Sidef::Types::Number::Number::ROUND);
+        }
+        else {
+            _valid(\$y);
+            my $f = Math::MPFR::Rmpfr_init2($PREC);
+            Math::MPC::Rmpc_abs($f, $$y, $ROUND);
+            Math::MPFR::Rmpfr_hypot($r, $r, $f, $Sidef::Types::Number::Number::ROUND);
+        }
+
+        Sidef::Types::Number::Number::_mpfr2big($r);
+    }
+
     sub log {
         my ($x, $y) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
@@ -969,6 +998,8 @@ package Sidef::Types::Number::Complex {
         (Sidef::Types::Bool::Bool::FALSE);
     }
 
+    sub float { $_[0] }
+
     {
         no strict 'refs';
 
