@@ -62,11 +62,15 @@ package Sidef::Types::Number::Nan {
     *shift_left        = \&nan;
     *shift_right       = \&nan;
     *factorial         = \&nan;
+    *fac               = \&nan;
+    *double_factorial  = \&nan;
+    *dfac              = \&nan;
     *not               = \&nan;
     *idiv              = \&nan;
     *gamma             = \&nan;
     *digamma           = \&nan;
     *zeta              = \&nan;
+    *eta               = \&nan;
     *log               = \&nan;
     *log2              = \&nan;
     *log10             = \&nan;
@@ -74,6 +78,7 @@ package Sidef::Types::Number::Nan {
     *mod               = \&nan;
     *imod              = \&nan;
     *fmod              = \&nan;
+    *frem              = \&nan;
     *ln                = \&nan;
     *exp               = \&nan;
     *exp2              = \&nan;
@@ -162,6 +167,8 @@ package Sidef::Types::Number::Nan {
     *big_omega         = \&nan;
     *prime_root        = \&nan;
     *prime_power       = \&nan;
+    *perfect_root      = \&nan;
+    *perfect_power     = \&nan;
     *partitions        = \&nan;
     *totient           = \&nan;
     *euler_phi         = \&nan;
@@ -178,6 +185,10 @@ package Sidef::Types::Number::Nan {
     *znprimroot        = \&nan;
     *ramanujan_tau     = \&nan;
     *prime_count       = \&nan;
+    *remove            = \&nan;
+    *rad               = \&nan;
+    *bessel_j          = \&nan;
+    *bessel_y          = \&nan;
 
     sub cmp { }
 
@@ -218,6 +229,7 @@ package Sidef::Types::Number::Nan {
     *is_prime          = \&is_real;
     *is_prob_prime     = \&is_real;
     *is_prov_prime     = \&is_real;
+    *is_mersenne_prime = \&is_real;
     *is_square_free    = \&is_real;
     *is_prime_power    = \&is_real;
     *is_primitive_root = \&is_real;
@@ -238,6 +250,10 @@ package Sidef::Types::Number::Nan {
         state $x = Sidef::Types::Number::Complex->new(0, NAN);
     }
 
+    sub cis {
+        state $x = Sidef::Types::Number::Complex->new(NAN, NAN);
+    }
+
     sub dump {
         state $x = Sidef::Types::String::String->new('NaN');
     }
@@ -278,13 +294,14 @@ package Sidef::Types::Number::Nan {
         Sidef::Types::Array::Array->new([]);
     }
 
-    *defs         = \&of;
-    *digits       = \&of;
-    *factor       = \&of;
-    *factors      = \&of;
-    *factor_pairs = \&of;
-    *primes       = \&of;
-    *divisors     = \&of;
+    *defs     = \&of;
+    *digits   = \&of;
+    *factor   = \&of;
+    *factors  = \&of;
+    *pfactor  = \&of;
+    *pfactors = \&of;
+    *primes   = \&of;
+    *divisors = \&of;
 
     sub times { $_[1] }
 
@@ -303,6 +320,9 @@ package Sidef::Types::Number::Nan {
     *isqrtrem = \&divmod;
     *irootrem = \&divmod;
 
+    sub seed { }
+    *iseed = \&seed;
+
     {
         no strict 'refs';
         *{__PACKAGE__ . '::' . '/'}   = \&div;
@@ -328,6 +348,7 @@ package Sidef::Types::Number::Nan {
         *{__PACKAGE__ . '::' . '!='}  = \&ne;
         *{__PACKAGE__ . '::' . '≠'} = \&ne;
         *{__PACKAGE__ . '::' . '!'}   = \&factorial;
+        *{__PACKAGE__ . '::' . '!!'}  = \&double_factorial;
         *{__PACKAGE__ . '::' . '%%'}  = \&is_div;
         *{__PACKAGE__ . '::' . '>>'}  = \&shift_right;
         *{__PACKAGE__ . '::' . '<<'}  = \&shift_left;
@@ -341,6 +362,7 @@ package Sidef::Types::Number::Nan {
         *{__PACKAGE__ . '::' . 'Ω'}  = \&big_omega;
         *{__PACKAGE__ . '::' . 'ω'}  = \&omega;
         *{__PACKAGE__ . '::' . 'ζ'}  = \&zeta;
+        *{__PACKAGE__ . '::' . 'η'}  = \&eta;
         *{__PACKAGE__ . '::' . 'μ'}  = \&mobius;
     }
 }
