@@ -70,6 +70,7 @@ package Sidef::Types::Number::Ninf {
     *digamma          = \&nan;
     *lngamma          = \&nan;
     *zeta             = \&nan;
+    *eta              = \&nan;
     *factorial        = \&nan;
     *fac              = \&nan;
     *double_factorial = \&nan;
@@ -391,6 +392,7 @@ package Sidef::Types::Number::Ninf {
         *{__PACKAGE__ . '::' . '≤'} = \&le;
         *{__PACKAGE__ . '::' . '<=>'} = \&cmp;
         *{__PACKAGE__ . '::' . '!'}   = \&factorial;
+        *{__PACKAGE__ . '::' . '!!'}  = \&double_factorial;
         *{__PACKAGE__ . '::' . '~'}   = \&not;
         *{__PACKAGE__ . '::' . '>>'}  = \&shift_right;
         *{__PACKAGE__ . '::' . '<<'}  = \&shift_left;
@@ -398,6 +400,7 @@ package Sidef::Types::Number::Ninf {
         *{__PACKAGE__ . '::' . 'Γ'}  = \&nan;
         *{__PACKAGE__ . '::' . 'Ψ'}  = \&nan;
         *{__PACKAGE__ . '::' . 'ζ'}  = \&zeta;
+        *{__PACKAGE__ . '::' . 'η'}  = \&eta;
     }
 }
 
