@@ -30,7 +30,7 @@ package Sidef::Types::Number::Number {
       );
 
     use overload
-      q{bool} => sub { Math::GMPq::Rmpq_sgn(${$_[0]}) != 0 },
+      q{bool} => sub { !!Math::GMPq::Rmpq_sgn(${$_[0]}) },
       q{0+}   => \&get_value,
       q{""}   => \&_big2str;
 
@@ -478,6 +478,14 @@ package Sidef::Types::Number::Number {
 
     sub iadd {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return $y;
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
         $x = _big2mpz($x);
         Math::GMPz::Rmpz_add($x, $x, _big2mpz($y));
@@ -486,6 +494,14 @@ package Sidef::Types::Number::Number {
 
     sub fadd {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return $y;
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
         $x = _big2mpfr($x);
         Math::MPFR::Rmpfr_add($x, $x, _big2mpfr($y), $ROUND);
@@ -512,6 +528,14 @@ package Sidef::Types::Number::Number {
 
     sub isub {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return $y->neg;
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
         $x = _big2mpz($x);
         Math::GMPz::Rmpz_sub($x, $x, _big2mpz($y));
@@ -520,6 +544,14 @@ package Sidef::Types::Number::Number {
 
     sub fsub {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return $y->neg;
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
         $x = _big2mpfr($x);
         Math::MPFR::Rmpfr_sub($x, $x, _big2mpfr($y), $ROUND);
@@ -547,6 +579,15 @@ package Sidef::Types::Number::Number {
 
     sub imul {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            my $sign = Math::GMPq::Rmpq_sgn($$x);
+            return ($sign < 0 ? $y->neg : $sign > 0 ? $y : nan());
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
         $x = _big2mpz($x);
         Math::GMPz::Rmpz_mul($x, $x, _big2mpz($y));
@@ -555,6 +596,15 @@ package Sidef::Types::Number::Number {
 
     sub fmul {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            my $sign = Math::GMPq::Rmpq_sgn($$x);
+            return ($sign < 0 ? $y->neg : $sign > 0 ? $y : nan());
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
         $x = _big2mpfr($x);
         Math::MPFR::Rmpfr_mul($x, $x, _big2mpfr($y), $ROUND);
@@ -590,6 +640,14 @@ package Sidef::Types::Number::Number {
 
     sub fdiv {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return (ZERO);
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
         $x = _big2mpfr($x);
         Math::MPFR::Rmpfr_div($x, $x, _big2mpfr($y), $ROUND);
@@ -598,6 +656,14 @@ package Sidef::Types::Number::Number {
 
     sub idiv {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return (ZERO);
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
         _valid(\$y);
 
         $x = _big2mpz($x);
@@ -668,10 +734,33 @@ package Sidef::Types::Number::Number {
 
     sub irootrem {
         my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            my $root = $x->iroot($y);
+            return ($root, $x->isub($root->ipow($y)));
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return ((nan()) x 2);
+        }
+
         _valid(\$y);
         $x = _big2mpz($x);
         my $root = CORE::int(Math::GMPq::Rmpq_get_d($$y));
-        ($root <= 0 or Math::GMPz::Rmpz_sgn($x) < 0) and return ((nan()) x 2);
+
+        if ($root == 0) {
+            Math::GMPz::Rmpz_sgn($x) || return (ZERO, MONE);    # 0^Inf = 0
+            Math::GMPz::Rmpz_cmpabs_ui($x, 1) == 0 and return (ONE, _mpz2big($x)->dec);    # 1^Inf = 1 ; (-1)^Inf = 1
+            return (inf(), _mpz2big($x)->dec);
+        }
+        elsif ($root < 0) {
+            my $sign = Math::GMPz::Rmpz_sgn($x) || return (inf(), ZERO);                   # 1 / 0^k = Inf
+            Math::GMPz::Rmpz_cmp_ui($x, 1) == 0 and return (ONE, ZERO);                    # 1 / 1^k = 1
+            return ($sign < 0 ? (nan(), nan()) : (ZERO, ninf()));
+        }
+        elsif ($root % 2 == 0 and Math::GMPz::Rmpz_sgn($x) < 0) {
+            return (nan(), nan());
+        }
+
         my $r = Math::GMPz::Rmpz_init();
         Math::GMPz::Rmpz_rootrem($x, $r, $x, $root);
         (_mpz2big($x), _mpz2big($r));
@@ -838,14 +927,6 @@ package Sidef::Types::Number::Number {
         _mpz2big($x);
     }
 
-    sub fmod {
-        my ($x, $y) = @_;
-        _valid(\$y);
-        $x = _big2mpfr($x);
-        Math::MPFR::Rmpfr_fmod($x, $x, _big2mpfr($y), $ROUND);
-        _mpfr2big($x);
-    }
-
     sub log {
         my ($x, $y) = @_;
 
@@ -1177,10 +1258,17 @@ package Sidef::Types::Number::Number {
     ## acoth(x) = atanh(1/x)
     #
     sub acoth {
-        my $r = _big2mpfr($_[0]);
-        Math::MPFR::Rmpfr_ui_div($r, 1, $r, $ROUND);
-        Math::MPFR::Rmpfr_atanh($r, $r, $ROUND);
-        _mpfr2big($r);
+        my ($x) = @_;
+
+        # Return a complex number for x > -1 and x < 1
+        if (Math::GMPq::Rmpq_cmp_ui($$x, 1, 1) < 0 and Math::GMPq::Rmpq_cmp_si($$x, -1, 1) > 0) {
+            return Sidef::Types::Number::Complex->new($x)->acoth;
+        }
+
+        $x = _big2mpfr($x);
+        Math::MPFR::Rmpfr_ui_div($x, 1, $x, $ROUND);
+        Math::MPFR::Rmpfr_atanh($x, $x, $ROUND);
+        _mpfr2big($x);
     }
 
     sub atan2 {
@@ -1210,6 +1298,21 @@ package Sidef::Types::Number::Number {
         _mpfr2big($x);
     }
 
+    sub cis {
+        state $_x = require Math::MPC;
+
+        my $cos = _big2mpfr($_[0]);
+        my $sin = Math::MPFR::Rmpfr_init2($PREC);
+        Math::MPFR::Rmpfr_set($sin, $cos, $ROUND);
+
+        Math::MPFR::Rmpfr_cos($cos, $cos, $ROUND);
+        Math::MPFR::Rmpfr_sin($sin, $sin, $ROUND);
+
+        my $r = Math::MPC::Rmpc_init2($PREC);
+        Math::MPC::Rmpc_set_fr_fr($r, $cos, $sin, $ROUND);
+        Sidef::Types::Number::Complex->new($r);
+    }
+
     #
     ## Special functions
     #
@@ -1254,6 +1357,31 @@ package Sidef::Types::Number::Number {
         _mpfr2big($r);
     }
 
+    #
+    ## eta(s) = (1 - 2^(1-s)) * zeta(s)
+    #
+    sub eta {
+        my $r = _big2mpfr($_[0]);
+
+        # Special case for eta(1) = log(2)
+        if (!Math::MPFR::Rmpfr_cmp_ui($r, 1)) {
+            Math::MPFR::Rmpfr_add_ui($r, $r, 1, $ROUND);
+            Math::MPFR::Rmpfr_log($r, $r, $ROUND);
+            return _mpfr2big($r);
+        }
+
+        my $p = Math::MPFR::Rmpfr_init2($PREC);
+        Math::MPFR::Rmpfr_set($p, $r, $ROUND);
+        Math::MPFR::Rmpfr_ui_sub($p, 1, $p, $ROUND);
+        Math::MPFR::Rmpfr_ui_pow($p, 2, $p, $ROUND);
+        Math::MPFR::Rmpfr_ui_sub($p, 1, $p, $ROUND);
+
+        Math::MPFR::Rmpfr_zeta($r, $r, $ROUND);
+        Math::MPFR::Rmpfr_mul($r, $r, $p, $ROUND);
+
+        _mpfr2big($r);
+    }
+
     sub zeta {
         my $r = _big2mpfr($_[0]);
         Math::MPFR::Rmpfr_zeta($r, $r, $ROUND);
@@ -1369,10 +1497,10 @@ package Sidef::Types::Number::Number {
 
         my $z = Math::GMPz::Rmpz_init();
         Math::GMPz::Rmpz_fac_ui($z, $n);              # z = n!
-        Math::GMPz::Rmpz_div_2exp($z, $z, $n - 1);    # z = z / 2^(n-1)
         Math::MPFR::Rmpfr_mul_z($f, $f, $z, $ROUND);  # f = f * z
+        Math::MPFR::Rmpfr_div_2exp($f, $f, $n - 1, $ROUND);    # f = f / 2^(n-1)
 
-        Math::MPFR::Rmpfr_div($f, $f, $p, $ROUND);    # f = f/p
+        Math::MPFR::Rmpfr_div($f, $f, $p, $ROUND);             # f = f/p
         Math::MPFR::Rmpfr_neg($f, $f, $ROUND) if $n % 4 == 0;
 
         _mpfr2big($f);
@@ -1492,6 +1620,54 @@ package Sidef::Types::Number::Number {
         _mpfr2big($r);
     }
 
+    sub bessel_j {
+        my ($x, $n) = @_;
+
+        $n = defined($n)
+          ? do {
+            _valid(\$n);
+            CORE::int(Math::GMPq::Rmpq_get_d($$n));
+          }
+          : 0;
+
+        $x = _big2mpfr($x);
+        if (!$n) {
+            Math::MPFR::Rmpfr_j0($x, $x, $ROUND);
+        }
+        elsif ($n == 1) {
+            Math::MPFR::Rmpfr_j1($x, $x, $ROUND);
+        }
+        else {
+            Math::MPFR::Rmpfr_jn($x, $n, $x, $ROUND);
+        }
+
+        _mpfr2big($x);
+    }
+
+    sub bessel_y {
+        my ($x, $n) = @_;
+
+        $n = defined($n)
+          ? do {
+            _valid(\$n);
+            CORE::int(Math::GMPq::Rmpq_get_d($$n));
+          }
+          : 0;
+
+        $x = _big2mpfr($x);
+        if (!$n) {
+            Math::MPFR::Rmpfr_y0($x, $x, $ROUND);
+        }
+        elsif ($n == 1) {
+            Math::MPFR::Rmpfr_y1($x, $x, $ROUND);
+        }
+        else {
+            Math::MPFR::Rmpfr_yn($x, $n, $x, $ROUND);
+        }
+
+        _mpfr2big($x);
+    }
+
     sub eint {
         my $r = _big2mpfr($_[0]);
         Math::MPFR::Rmpfr_eint($r, $r, $ROUND);
@@ -1519,6 +1695,10 @@ package Sidef::Types::Number::Number {
 
     sub eq {
         my ($x, $y) = @_;
+
+        ref($y) ne __PACKAGE__
+          and return Sidef::Types::Bool::Bool::FALSE;
+
         _valid(\$y);
         Math::GMPq::Rmpq_equal($$x, $$y)
           ? (Sidef::Types::Bool::Bool::TRUE)
@@ -1527,6 +1707,10 @@ package Sidef::Types::Number::Number {
 
     sub ne {
         my ($x, $y) = @_;
+
+        ref($y) ne __PACKAGE__
+          and return Sidef::Types::Bool::Bool::TRUE;
+
         _valid(\$y);
         Math::GMPq::Rmpq_equal($$x, $$y)
           ? (Sidef::Types::Bool::Bool::FALSE)
@@ -2041,6 +2225,34 @@ package Sidef::Types::Number::Number {
         }
     }
 
+    sub fmod {
+        my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return (Math::GMPq::Rmpq_sgn($$x) == Math::GMPq::Rmpq_sgn($$y) ? $x : $y);
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
+        _valid(\$y);
+
+        $x = _big2mpfr($x);
+        $y = _big2mpfr($y);
+
+        Math::MPFR::Rmpfr_fmod($x, $x, $y, $ROUND);
+
+        my $sign_r = Math::MPFR::Rmpfr_sgn($x);
+        if (!$sign_r) {
+            return ZERO;    # return faster
+        }
+        elsif ($sign_r > 0 xor Math::MPFR::Rmpfr_sgn($y) > 0) {
+            Math::MPFR::Rmpfr_add($x, $x, $y, $ROUND);
+        }
+
+        _mpfr2big($x);
+    }
+
     sub imod {
         my ($x, $y) = @_;
 
@@ -2064,6 +2276,22 @@ package Sidef::Types::Number::Number {
         _mpz2big($x);
     }
 
+    sub frem {
+        my ($x, $y) = @_;
+
+        if (ref($y) eq 'Sidef::Types::Number::Inf' or ref($y) eq 'Sidef::Types::Number::Ninf') {
+            return $x;
+        }
+        elsif (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return nan();
+        }
+
+        _valid(\$y);
+        $x = _big2mpfr($x);
+        Math::MPFR::Rmpfr_fmod($x, $x, _big2mpfr($y), $ROUND);
+        _mpfr2big($x);
+    }
+
     sub modpow {
         my ($x, $y, $z) = @_;
         _valid(\$y, \$z);
@@ -2334,6 +2562,16 @@ package Sidef::Types::Number::Number {
         __PACKAGE__->_set_uint(Math::GMPz::Rmpz_remove($x, $x, $z));
     }
 
+    sub remove {
+        my ($x, $y) = @_;
+        _valid(\$y);
+        my $z = _big2mpz($y);
+        Math::GMPz::Rmpz_sgn($z) || return ZERO;
+        $x = _big2mpz($x);
+        Math::GMPz::Rmpz_remove($x, $x, $z);
+        _mpz2big($x);
+    }
+
     sub is_prime {
         my $x = ${$_[0]};
         Math::GMPq::Rmpq_integer_p($x)
@@ -2362,6 +2600,14 @@ package Sidef::Types::Number::Number {
           : Sidef::Types::Bool::Bool::FALSE;
     }
 
+    sub is_mersenne_prime {
+        my $x = ${$_[0]};
+        Math::GMPq::Rmpq_integer_p($x)
+          && Math::Prime::Util::GMP::is_mersenne_prime(Math::GMPq::Rmpq_get_str($x, 10))
+          ? Sidef::Types::Bool::Bool::TRUE
+          : Sidef::Types::Bool::Bool::FALSE;
+    }
+
     sub primes {
         my ($x, $y) = @_;
 
@@ -2405,6 +2651,13 @@ package Sidef::Types::Number::Number {
         $n <= MAX_UI ? __PACKAGE__->_set_uint($n) : __PACKAGE__->_set_str($n);
     }
 
+    sub rad {
+        my %f;
+        @f{Math::Prime::Util::GMP::factor(&_big2istr)} = ();
+        my $n = Math::Prime::Util::GMP::vecprod(CORE::keys %f);
+        $n <= MAX_UI ? __PACKAGE__->_set_uint($n) : __PACKAGE__->_set_str($n);
+    }
+
     sub factor {
         Sidef::Types::Array::Array->new(
             [
@@ -2422,30 +2675,30 @@ package Sidef::Types::Number::Number {
 
     *factors = \&factor;
 
-    sub factor_pairs {
+    sub pfactor {
         my %count;
         foreach my $f (Math::Prime::Util::GMP::factor(&_big2istr)) {
             ++$count{$f};
         }
 
         my @pairs;
-        foreach my $factor (sort keys(%count)) {
+        foreach my $factor (sort { (CORE::length($a) <=> CORE::length($b)) || ($a cmp $b) } keys(%count)) {
             push @pairs,
-              Sidef::Types::Array::Array->new(
-                                              [
-                                               (
-                                                $_ <= MAX_UI
-                                                ? __PACKAGE__->_set_uint($factor)
-                                                : __PACKAGE__->_set_str($factor)
-                                               ),
-                                               __PACKAGE__->_set_uint($count{$factor})
-                                              ]
-                                             );
+              Sidef::Types::Array::Pair->new(
+                                             (
+                                              $factor <= MAX_UI
+                                              ? __PACKAGE__->_set_uint($factor)
+                                              : __PACKAGE__->_set_str($factor)
+                                             ),
+                                             __PACKAGE__->_set_uint($count{$factor})
+                                            );
         }
 
         Sidef::Types::Array::Array->new(\@pairs);
     }
 
+    *pfactors = \&pfactor;
+
     sub divisors {
         Sidef::Types::Array::Array->new(
             [
@@ -2634,6 +2887,22 @@ package Sidef::Types::Number::Number {
         $pow == 1 ? ONE : __PACKAGE__->_set_uint($pow);
     }
 
+    sub perfect_root {
+        my $str = &_big2istr;
+
+        my $pow = Math::Prime::Util::GMP::is_power($str) || return $_[0];
+
+        my $x = Math::GMPz::Rmpz_init_set_str($str, 10);
+        $pow == 2
+          ? Math::GMPz::Rmpz_sqrt($x, $x)
+          : Math::GMPz::Rmpz_root($x, $x, $pow);
+        _mpz2big($x);
+    }
+
+    sub perfect_power {
+        __PACKAGE__->_set_uint(Math::Prime::Util::GMP::is_power(&_big2istr) || return ONE);
+    }
+
     sub next_pow2 {
         my ($x) = @_;
 
@@ -2843,75 +3112,89 @@ package Sidef::Types::Number::Number {
           : (ZERO)->to($from->dec);
     }
 
-    sub rand {
-        my ($x, $y) = @_;
-
+    {
         state $state = Math::MPFR::Rmpfr_randinit_mt_nobless();
-        state $seed = Math::MPFR::Rmpfr_randseed_ui($state, scalar srand());
+        Math::MPFR::Rmpfr_randseed_ui($state, scalar srand());
 
-        Math::MPFR::Rmpfr_urandom((my $rand = Math::MPFR::Rmpfr_init2($PREC)), $state, $ROUND);
-        Math::MPFR::Rmpfr_get_q((my $q = Math::GMPq::Rmpq_init()), $rand);
+        sub rand {
+            my ($x, $y) = @_;
 
-        if (defined $y) {
+            Math::MPFR::Rmpfr_urandom((my $rand = Math::MPFR::Rmpfr_init2($PREC)), $state, $ROUND);
+            Math::MPFR::Rmpfr_get_q((my $q = Math::GMPq::Rmpq_init()), $rand);
 
-            if (   ref($y) eq 'Sidef::Types::Number::Inf'
-                or ref($y) eq 'Sidef::Types::Number::Ninf'
-                or ref($y) eq 'Sidef::Types::Number::Nan') {
-                return $y;
+            if (defined $y) {
+
+                if (   ref($y) eq 'Sidef::Types::Number::Inf'
+                    or ref($y) eq 'Sidef::Types::Number::Ninf'
+                    or ref($y) eq 'Sidef::Types::Number::Nan') {
+                    return $y;
+                }
+
+                _valid(\$y);
+
+                Math::GMPq::Rmpq_sub((my $diff = Math::GMPq::Rmpq_init()), $$y, $$x);
+                Math::GMPq::Rmpq_mul($q, $q, $diff);
+                Math::GMPq::Rmpq_add($q, $q, $$x);
+            }
+            else {
+                Math::GMPq::Rmpq_mul($q, $q, $$x);
             }
 
-            _valid(\$y);
-
-            Math::GMPq::Rmpq_sub((my $diff = Math::GMPq::Rmpq_init()), $$y, $$x);
-            Math::GMPq::Rmpq_mul($q, $q, $diff);
-            Math::GMPq::Rmpq_add($q, $q, $$x);
-        }
-        else {
-            Math::GMPq::Rmpq_mul($q, $q, $$x);
+            bless \$q, __PACKAGE__;
         }
 
-        bless \$q, __PACKAGE__;
+        sub seed {
+            Math::MPFR::Rmpfr_randseed($state, _big2mpz($_[0]));
+            $_[0];
+        }
     }
 
-    sub irand {
-        my ($x, $y) = @_;
-
+    {
         state $state = Math::GMPz::zgmp_randinit_mt_nobless();
-        state $seed = Math::GMPz::zgmp_randseed_ui($state, scalar srand());
+        Math::GMPz::zgmp_randseed_ui($state, scalar srand());
 
-        $x = _big2mpz($x);
+        sub irand {
+            my ($x, $y) = @_;
 
-        if (defined($y)) {
+            $x = _big2mpz($x);
 
-            if (   ref($y) eq 'Sidef::Types::Number::Inf'
-                or ref($y) eq 'Sidef::Types::Number::Ninf'
-                or ref($y) eq 'Sidef::Types::Number::Nan') {
-                return $y;
+            if (defined($y)) {
+
+                if (   ref($y) eq 'Sidef::Types::Number::Inf'
+                    or ref($y) eq 'Sidef::Types::Number::Ninf'
+                    or ref($y) eq 'Sidef::Types::Number::Nan') {
+                    return $y;
+                }
+
+                _valid(\$y);
+
+                my $rand = _big2mpz($y);
+                my $cmp = Math::GMPz::Rmpz_cmp($rand, $x);
+
+                if ($cmp == 0) {
+                    return _mpz2big($rand);
+                }
+                elsif ($cmp < 0) {
+                    ($x, $rand) = ($rand, $x);
+                }
+
+                Math::GMPz::Rmpz_sub($rand, $rand, $x);
+                Math::GMPz::Rmpz_urandomm($rand, $state, $rand, 1);
+                Math::GMPz::Rmpz_add($rand, $rand, $x);
+
+                _mpz2big($rand);
             }
-
-            _valid(\$y);
-
-            my $rand = _big2mpz($y);
-            my $cmp = Math::GMPz::Rmpz_cmp($rand, $x);
-
-            if ($cmp == 0) {
-                return _mpz2big($rand);
+            else {
+                my $sgn = Math::GMPz::Rmpz_sgn($x) || return ZERO;
+                Math::GMPz::Rmpz_urandomm($x, $state, $x, 1);
+                Math::GMPz::Rmpz_neg($x, $x) if $sgn < 0;
+                _mpz2big($x);
             }
-            elsif ($cmp < 0) {
-                ($x, $rand) = ($rand, $x);
-            }
-
-            Math::GMPz::Rmpz_sub($rand, $rand, $x);
-            Math::GMPz::Rmpz_urandomm($rand, $state, $rand, 1);
-            Math::GMPz::Rmpz_add($rand, $rand, $x);
-
-            _mpz2big($rand);
         }
-        else {
-            my $sgn = Math::GMPz::Rmpz_sgn($x);
-            Math::GMPz::Rmpz_urandomm($x, $state, $x, 1);
-            Math::GMPz::Rmpz_neg($x, $x) if $sgn < 0;
-            _mpz2big($x);
+
+        sub iseed {
+            Math::GMPz::zgmp_randseed($state, _big2mpz($_[0]));
+            $_[0];
         }
     }
 
@@ -3012,43 +3295,31 @@ package Sidef::Types::Number::Number {
     #
 
     sub rad2deg {
-        my ($x) = @_;
-        state $f = do {
-            Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
-            Math::MPFR::Rmpfr_ui_div((my $fr = Math::MPFR::Rmpfr_init2($PREC)), 180, $pi, $ROUND);
-            _mpfr2big($fr);
-        };
-        $f->mul($x);
+        Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
+        Math::MPFR::Rmpfr_ui_div((my $fr = Math::MPFR::Rmpfr_init2($PREC)), 180, $pi, $ROUND);
+        Math::MPFR::Rmpfr_mul_q($fr, $fr, ${$_[0]}, $ROUND);
+        _mpfr2big($fr);
     }
 
     sub deg2rad {
-        my ($x) = @_;
-        state $f = do {
-            Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
-            Math::MPFR::Rmpfr_div_ui((my $fr = Math::MPFR::Rmpfr_init2($PREC)), $pi, 180, $ROUND);
-            _mpfr2big($fr);
-        };
-        $f->mul($x);
+        Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
+        Math::MPFR::Rmpfr_div_ui((my $fr = Math::MPFR::Rmpfr_init2($PREC)), $pi, 180, $ROUND);
+        Math::MPFR::Rmpfr_mul_q($fr, $fr, ${$_[0]}, $ROUND);
+        _mpfr2big($fr);
     }
 
     sub rad2grad {
-        my ($x) = @_;
-        state $factor = do {
-            Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
-            Math::MPFR::Rmpfr_ui_div((my $fr = Math::MPFR::Rmpfr_init2($PREC)), 200, $pi, $ROUND);
-            _mpfr2big($fr);
-        };
-        $factor->mul($x);
+        Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
+        Math::MPFR::Rmpfr_ui_div((my $fr = Math::MPFR::Rmpfr_init2($PREC)), 200, $pi, $ROUND);
+        Math::MPFR::Rmpfr_mul_q($fr, $fr, ${$_[0]}, $ROUND);
+        _mpfr2big($fr);
     }
 
     sub grad2rad {
-        my ($x) = @_;
-        state $factor = do {
-            Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
-            Math::MPFR::Rmpfr_div_ui((my $fr = Math::MPFR::Rmpfr_init2($PREC)), $pi, 200, $ROUND);
-            _mpfr2big($fr);
-        };
-        $factor->mul($x);
+        Math::MPFR::Rmpfr_const_pi((my $pi = Math::MPFR::Rmpfr_init2($PREC)), $ROUND);
+        Math::MPFR::Rmpfr_div_ui((my $fr = Math::MPFR::Rmpfr_init2($PREC)), $pi, 200, $ROUND);
+        Math::MPFR::Rmpfr_mul_q($fr, $fr, ${$_[0]}, $ROUND);
+        _mpfr2big($fr);
     }
 
     sub grad2deg {
@@ -3100,6 +3371,7 @@ package Sidef::Types::Number::Number {
         *{__PACKAGE__ . '::' . '..^'} = \&xto;
         *{__PACKAGE__ . '::' . '^..'} = \&xdownto;
         *{__PACKAGE__ . '::' . '!'}   = \&factorial;
+        *{__PACKAGE__ . '::' . '!!'}  = \&double_factorial;
         *{__PACKAGE__ . '::' . '%%'}  = \&is_div;
         *{__PACKAGE__ . '::' . '>>'}  = \&shift_right;
         *{__PACKAGE__ . '::' . '<<'}  = \&shift_left;
@@ -3114,6 +3386,7 @@ package Sidef::Types::Number::Number {
         *{__PACKAGE__ . '::' . 'Ω'}  = \&big_omega;
         *{__PACKAGE__ . '::' . 'ω'}  = \&omega;
         *{__PACKAGE__ . '::' . 'ζ'}  = \&zeta;
+        *{__PACKAGE__ . '::' . 'η'}  = \&eta;
         *{__PACKAGE__ . '::' . 'μ'}  = \&mobius;
     }
 }
