@@ -10,7 +10,7 @@ package Sidef::Types::String::String {
 
     use overload
       q{bool} => \&get_value,
-      q{0+}   => sub { ${$_[0]} },
+      q{0+}   => \&get_value,
       q{""}   => \&get_value;
 
     use Sidef::Types::Bool::Bool;
@@ -333,6 +333,26 @@ package Sidef::Types::String::String {
         Sidef::Types::Number::Number->new($$self, 16);
     }
 
+    sub md5 {
+        state $x = require Digest::MD5;
+        bless(\(my $o = Digest::MD5::md5_hex(${$_[0]})), __PACKAGE__);
+    }
+
+    sub sha1 {
+        state $x = require Digest::SHA;
+        bless(\(my $o = Digest::SHA::sha1_hex(${$_[0]})), __PACKAGE__);
+    }
+
+    sub sha256 {
+        state $x = require Digest::SHA;
+        bless(\(my $o = Digest::SHA::sha256_hex(${$_[0]})), __PACKAGE__);
+    }
+
+    sub sha512 {
+        state $x = require Digest::SHA;
+        bless(\(my $o = Digest::SHA::sha512_hex(${$_[0]})), __PACKAGE__);
+    }
+
     sub substr {
         my ($self, $offs, $len) = @_;
         __PACKAGE__->new(
@@ -1210,9 +1230,6 @@ package Sidef::Types::String::String {
                         splice @chars, $i, 1 + $+[0], CORE::chr(CORE::oct($1));
                     }
                 }
-                elsif ($char eq 'd') {
-                    splice(@chars, $i - 1, 3);
-                }
                 elsif ($char eq 'c') {
                     if (exists $chars[$i + 2]) {    # bug for: "\c\\"
                         splice(@chars, $i, 3, chr((CORE::ord(CORE::uc($chars[$i + 2])) + 64) % 128));
@@ -1240,7 +1257,7 @@ package Sidef::Types::String::String {
                 }
             }
 
-            if ($spec ne 'E') {
+            if ($spec ne 'E' and defined($chars[$i])) {
                 if ($spec eq 'U') {
                     $chars[$i] = CORE::uc($chars[$i]);
                 }
